<?php

namespace GeorgGriesser\WordPress\Smart_WP\Header_Manager;

use GeorgGriesser\WordPress\Smart_WP\Header_Generator;

class Archive_Header_Manager extends Header_Manager
{
    protected $supported_post_types_filter_name = 'smart_wp_supported_post_types_archive';
    protected $post_filter_name = 'smart_wp_post_archive';

    /**
     * Sets headers on archives
     *
     * WordPress archives list the posts that belong to the archive from
     * newest to oldest. We set the HTTP headers for the archive page based
     * on the first post of the archive (newest).
     * There is no need to check for pagination, since every page of the archive
     * has different posts.
     *
     */
    function set_headers($post)
    {

        // Allow filtering to use another post
        $post = apply_filters('addh_archive_post', $post);

        if (!$this->is_valid_post_type($post)) {
            return;
        }

        $post_modified_time = $post->post_modified_gmt;
        $modified_time = strtotime($post_modified_time);

        $this->headers = Header_Generator::batch_generate_headers($post, $modified_time, $this->options);
    }
}