<?php

namespace GeorgGriesser\WordPress\Smart_WP\Header_Manager;

abstract class Header_Manager
{
    protected $supported_post_types_filter_name;
    protected $headers;
    protected $options;

    public function __construct($options)
    {
        $this->options = $options;
    }

    abstract function set_headers($post);

    public function send_headers()
    {

        if (empty($this->headers)) {
            return;
        }

        // Check if headers have already been sent and, if yes, generate friendly warning.
        if (headers_sent()) {
            $warning_message = 'Smart-WordPress tried to append its headers to the headers list, but the header list had already been sent to the client by other code. This is not a problem caused by the Smart-WordPress plugin. Moreover, the Smart-WordPress plugin can do nothing about this issue. Please investigate which plugin or theme sends the headers earlier than what is expected.';
            trigger_error($warning_message, E_USER_WARNING);
            return;
        }

        // Clean up pre-existing headers
        if (array_key_exists('remove_pre_existing_headers', $this->options) && $this->options['remove_pre_existing_headers'] === true) {
            $current_headers = headers_list();
            $supported_headers = array('ETag', 'Last-Modified', 'Expires', 'Cache-Control', 'Pragma');
            foreach ($current_headers as $current_header) {
                foreach ($supported_headers as $supported_header) {
                    if (strpos($current_header, $supported_header) === false) {
                        header_remove($supported_header);
                    }
                }
            }
        }

        // Send the headers
        foreach ($this->headers as $header_name => $header_value) {
            if (!empty($header_name) && !empty($header_value)) {

                header(sprintf('%s: %s', $header_name, $header_value));
            }
        }
    }


    /**
     * @param $post
     * @return bool
     */
    protected function is_valid_post_type($post)
    {
        if (!is_object($post) || !isset($post->post_type) || !in_array(get_post_type($post), $this->get_supported_post_types())) {
            return false;
        }

        return true;
    }

    /**
     * @return array
     */
    protected function get_supported_post_types()
    {
        $supported_builtin_types = array('post', 'page', 'attachment');
        $public_custom_types = get_post_types(array('public' => true, '_builtin' => false));

        $supported_types = array_merge($supported_builtin_types, $public_custom_types);

        // Allow filtering
        $supported_types = apply_filters($this->supported_post_types_filter_name, $supported_types);

        return $supported_types;
    }

    public function get_headers()
    {
        return $this->headers;
    }
}