<?php

namespace GeorgGriesser\WordPress\Smart_WP;

class Setting
{
    const SMART_WP_OPTION_NAME = 'smart-wp-option';

    public static function get()
    {
        return get_option(self::SMART_WP_OPTION_NAME, self::get_default());

    }

    public static function update($input)
    {
        $input = self::sanitize($input);

        $input = self::merge_into_existing_settings($input);

        return update_option(self::SMART_WP_OPTION_NAME, $input, true);
    }

    public static function delete()
    {
        return delete_option(self::SMART_WP_OPTION_NAME);
    }

    private static function get_default()
    {
        return array(
            'add_etag_header' => true,
            'generate_weak_etag' => true,
            'add_last_modified_header' => true,
            'add_cache_control_header' => true,
            'cache_max_age_seconds' => 3600,
            'cache_max_age_seconds_for_search_results' => 0,
            'cache_max_age_seconds_for_authenticated_users' => 0,
            'cache_old_content_threshold_seconds' => 0,
            'cache_old_content_max_age_seconds' => 0,
            'remove_pre_existing_headers' => false,

        );
    }

    public static function sanitize($input)
    {
        return array_map("wp_kses_post", $input);
    }

    private static function merge_into_existing_settings($input)
    {
        $existing = self::get();

        return array_merge(
            $existing,
            array_intersect_key($input, $existing)
        );
    }
}